spacr.gui — spacr 0.5.0 documentation

# spacr.gui

## Module Contents

class spacr.gui.MainApp(default_app=None)

  Bases: `tkinter.Tk`

  Toplevel widget of Tk which represents mostly the main window of an application. It has an associated Tcl interpreter.

  color_settings
  main_buttons
  additional_buttons
  main_gui_apps
  additional_gui_apps
  selected_app
  create_widgets()
  create_startup_screen()
  update_description()
  show_description(description)
  clear_description()
  load_app(app_name, app_func)
  clear_frame(frame)

spacr.gui.gui_app()